@@ -1,4 +1,5 @@
-# $Id: Checkout.pm 738 2005-08-20 02:55:45Z claco $
+# $Id: Checkout.pm 1415 2006-09-14 00:54:13Z claco $
+## no critic
 package AxKit::XSP::Handel::Checkout;
 use strict;
 use warnings;
@@ -43,7 +44,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Checkout';
         if ($tag eq 'new') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid inside of other Handel tags", $tag)
-            ) if ($context[$#context] ne 'root');
+            ) if ($context[-1] ne 'root');
 
             push @context, $tag;
 
@@ -67,8 +68,8 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Checkout';
             return $code;
         } elsif ($tag eq 'plugin') {
             throw Handel::Exception::Taglib(
-                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[$#context] . "'", $tag)
-            ) if ($context[$#context] ne 'plugins');
+                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[-1] . "'", $tag)
+            ) if ($context[-1] ne 'plugins');
 
             push @context, $tag;
 
@@ -95,8 +96,8 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Checkout';
             undef $property if ($property eq 'checkout');
 
             throw Handel::Exception::Taglib(
-                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[$#context] . "'", $tag)
-            ) if ($context[$#context] ne 'messages');
+                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[-1] . "'", $tag)
+            ) if ($context[-1] ne 'messages');
 
             push @context, $tag;
 
@@ -134,8 +135,8 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Checkout';
             return $code;
         } elsif ($tag eq 'phase') {
             throw Handel::Exception::Taglib(
-                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[$#context] . "'", $tag)
-            ) if ($context[$#context] ne 'phases');
+                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[-1] . "'", $tag)
+            ) if ($context[-1] ne 'phases');
 
             push @context, $tag;
 
@@ -419,7 +420,7 @@ the orders uuid value:
 
 =head2 <checkout:ok>
 
-If process suceeds, anything in the ok block is run:
+If process succeeds, anything in the ok block is run:
 
     <checkout:new>
         <checkout:process>
