@@ -1,4 +1,5 @@
-# $Id: Order.pm 1355 2006-08-07 01:51:41Z claco $
+# $Id: Order.pm 1415 2006-09-14 00:54:13Z claco $
+## no critic
 package AxKit::XSP::Handel::Order;
 use strict;
 use warnings;
@@ -50,21 +51,21 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         shiptocity|shiptostate|shiptozip|shiptocountry|
         shiptodayphone|shiptonightphone|shiptofax|shiptoemail|
         tax|subtotal|total||updated)$/x) {
-            if ($context[$#context] eq 'new') {
+            if ($context[-1] eq 'new') {
                 return ".q|$text|";
-            } elsif ($context[$#context] eq 'add') {
+            } elsif ($context[-1] eq 'add') {
                 return ".q|$text|";
-            } elsif ($context[$#context] eq 'delete') {
+            } elsif ($context[-1] eq 'delete') {
                 return ".q|$text|";
-            } elsif ($context[$#context] eq 'update') {
+            } elsif ($context[-1] eq 'update') {
                 return ".q|$text|";
             };
         } elsif ($tag =~ /^(sku|price|quantity)$/) {
-            if ($context[$#context] eq 'add') {
+            if ($context[-1] eq 'add') {
                 return ".q|$text|";
-            } elsif ($context[$#context] eq 'delete') {
+            } elsif ($context[-1] eq 'delete') {
                 return ".q|$text|";
-            } elsif ($context[$#context] eq 'update') {
+            } elsif ($context[-1] eq 'update') {
                 return ".q|$text|";
             };
         } elsif ($tag eq 'filter') {
@@ -94,7 +95,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag eq 'new') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid inside of other Handel tags", $tag)
-            ) if ($context[$#context] ne 'root');
+            ) if ($context[-1] ne 'root');
 
             push @context, $tag;
 
@@ -113,7 +114,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag eq 'cart') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] ne 'new');
+            ) if ($context[-1] ne 'new');
 
             push @context, $tag;
 
@@ -128,7 +129,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag eq 'order') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid inside of other Handel tags", $tag)
-            ) if ($context[$#context] ne 'root');
+            ) if ($context[-1] ne 'root');
 
             push @context, $tag;
 
@@ -144,7 +145,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag eq 'orders') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid inside of other Handel tags", $tag)
-            ) if ($context[$#context] ne 'root');
+            ) if ($context[-1] ne 'root');
 
             push @context, $tag;
 
@@ -159,8 +160,8 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         ## order:item
         } elsif ($tag eq 'item') {
             throw Handel::Exception::Taglib(
-                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[$#context] . "'", $tag)
-            ) if ($context[$#context] =~ /^(order(s?))$/);
+                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[-1] . "'", $tag)
+            ) if ($context[-1] =~ /^(order(s?))$/);
 
             push @context, $tag;
 
@@ -175,8 +176,8 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         ## order:items
         } elsif ($tag eq 'items') {
             throw Handel::Exception::Taglib(
-                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[$#context] . "'", $tag)
-            ) if ($context[$#context] =~ /^(order(s?))$/);
+                -text => translate("Tag '[_1]' not valid inside of tag '" . $context[-1] . "'", $tag)
+            ) if ($context[-1] =~ /^(order(s?))$/);
 
             push @context, $tag;
 
@@ -192,7 +193,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag eq 'clear') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] ne 'results' || $context[$#context-1] !~ /^(order(s?))$/);
+            ) if ($context[-1] ne 'results' || $context[-2] !~ /^(order(s?))$/);
 
            return "\n\$_xsp_handel_order_order->clear;\n";
 
@@ -201,7 +202,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag eq 'add') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] ne 'results' || $context[$#context-1] !~ /^(new|order(s?))$/);
+            ) if ($context[-1] ne 'results' || $context[-2] !~ /^(new|order(s?))$/);
 
             push @context, $tag;
 
@@ -217,13 +218,13 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag eq 'update') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] ne 'results' || $context[$#context-1] !~ /^((order(s?)|item(s?)))$/);
+            ) if ($context[-1] ne 'results' || $context[-2] !~ /^((order(s?)|item(s?)))$/);
 
             push @context, $tag;
 
-            if ($context[$#context-2] =~ /^(order(s?))$/) {
+            if ($context[-3] =~ /^(order(s?))$/) {
                 return "\n\$_xsp_handel_order_order->autoupdate(0);\n";
-            } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+            } elsif ($context[-3] =~ /^(item(s?))$/) {
                 return "\n\$_xsp_handel_order_item->autoupdate(0);\n";
             };
 
@@ -233,7 +234,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag eq 'save') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context-1] !~ /^(order(s?))$/);
+            ) if ($context[-2] !~ /^(order(s?))$/);
 
             return '
                 $_xsp_handel_order_order->save;
@@ -244,7 +245,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag eq 'delete') {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] ne 'results' || $context[$#context-1] !~ /^(order(s?))$/);
+            ) if ($context[-1] ne 'results' || $context[-2] !~ /^(order(s?))$/);
 
             push @context, $tag;
 
@@ -267,11 +268,11 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         shiptocity|shiptostate|shiptozip|shiptocountry|
         shiptodayphone|shiptonightphone|shiptofax|shiptoemail|
         tax|subtotal|updated)$/x) {
-            if ($context[$#context] eq 'new' && $tag !~ /^(count)$/) {
+            if ($context[-1] eq 'new' && $tag !~ /^(count)$/) {
                 return "\n\$_xsp_handel_order_new_filter{$tag} = ''";
-            } elsif ($context[$#context] eq 'add' && $tag =~ /^(id|description)$/) {
+            } elsif ($context[-1] eq 'add' && $tag =~ /^(id|description)$/) {
                 return "\n\$_xsp_handel_order_add_filter{$tag} = ''";
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] =~ /^(new|order(s?))$/) {
+            } elsif ($context[-1] eq 'results' && $context[-2] =~ /^(new|order(s?))$/) {
                 $e->start_expr($tag);
 
                 if ($tag =~ /^(subtotal|tax|handling|shipping)$/ && ($attr{'format'} || $attr{'convert'})) {
@@ -291,25 +292,25 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                 } else {
                     $e->append_to_script("\$_xsp_handel_order_order->$tag;\n");
                 };
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'item') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'item') {
                 $e->start_expr($tag);
                 $e->append_to_script("\$_xsp_handel_order_item->$tag;\n");
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'items') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'items') {
                 $e->start_expr($tag);
                 $e->append_to_script("\$_xsp_handel_order_item->$tag;\n");
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'add') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'add') {
                 $e->start_expr($tag);
                 $e->append_to_script("\$_xsp_handel_order_item->$tag;\n");
-            } elsif ($context[$#context] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
+            } elsif ($context[-1] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
                 return "\n\$_xsp_handel_order_delete_filter{$tag} = ''";
-            } elsif ($context[$#context] eq 'update') {
+            } elsif ($context[-1] eq 'update') {
                 throw Handel::Exception::Taglib(
                     -text => translate("Tag '[_1]' not valid here", $tag)
                 ) if ($tag eq 'id');
 
-                if ($context[$#context-2] =~ /^(order(s?))$/) {
+                if ($context[-3] =~ /^(order(s?))$/) {
                     return "\n\$_xsp_handel_order_order->$tag(''";
-                } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+                } elsif ($context[-3] =~ /^(item(s?))$/) {
                     return "\n\$_xsp_handel_order_item->$tag(''";
                 };
             };
@@ -318,14 +319,14 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         ## order item property tags
         ## order:sku, price, quantity, total
         } elsif ($tag =~ /^(sku|price|quantity|total)$/) {
-            if ($context[$#context] eq 'new') {
+            if ($context[-1] eq 'new') {
                 return "\n\$_xsp_handel_order_new_filter{$tag} = ''";
-            } elsif ($context[$#context] eq 'add') {
+            } elsif ($context[-1] eq 'add') {
                 return "\n\$_xsp_handel_order_add_filter{$tag} = ''";
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'add') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'add') {
                 $e->start_expr($tag);
                 $e->append_to_script("\$_xsp_handel_order_item->$tag;\n");
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] =~ /^(new|order(s?)|item(s?))$/) {
+            } elsif ($context[-1] eq 'results' && $context[-2] =~ /^(new|order(s?)|item(s?))$/) {
                 $e->start_expr($tag);
 
                 if ($tag =~ /^(price|total)$/ && ($attr{'format'} || $attr{'convert'})) {
@@ -338,31 +339,31 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                     AxKit::Debug(5, "[Handel] [Order] [$tag] code=$code, format=$format, from=$from, to=$to");
 
                     if ($attr{'convert'}) {
-                        if ($context[$#context-1] =~ /^(new|order(s?))$/) {
+                        if ($context[-2] =~ /^(new|order(s?))$/) {
                             $e->append_to_script("\$_xsp_handel_order_order->$tag->convert('$from', '$to', '".($attr{'format'}||'')."', '$format');\n");
                         } else {
                             $e->append_to_script("\$_xsp_handel_order_item->$tag->convert('$from', '$to', '".($attr{'format'}||'')."', '$format');\n");
                         };
                     } elsif ($attr{'format'}) {
-                        if ($context[$#context-1] =~ /^(new|order(s?))$/) {
+                        if ($context[-2] =~ /^(new|order(s?))$/) {
                             $e->append_to_script("\$_xsp_handel_order_order->$tag->format('$code', '$format');\n");
                         } else {
                             $e->append_to_script("\$_xsp_handel_order_item->$tag->format('$code', '$format');\n");
                         };
                     };
                 } else {
-                    if ($context[$#context-1] =~ /^(new|order(s?))$/) {
+                    if ($context[-2] =~ /^(new|order(s?))$/) {
                         $e->append_to_script("\$_xsp_handel_order_order->$tag;\n");
                     } else {
                         $e->append_to_script("\$_xsp_handel_order_item->$tag;\n");
                     };
                 };
-            } elsif ($context[$#context] eq 'delete') {
+            } elsif ($context[-1] eq 'delete') {
                 return "\n\$_xsp_handel_order_delete_filter{$tag} = ''";
-            } elsif ($context[$#context] eq 'update') {
-                if ($context[$#context-2] =~ /^(order(s?))$/) {
+            } elsif ($context[-1] eq 'update') {
+                if ($context[-3] =~ /^(order(s?))$/) {
                     return "\n\$_xsp_handel_order_order->$tag(''";
-                } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+                } elsif ($context[-3] =~ /^(item(s?))$/) {
                     return "\n\$_xsp_handel_order_item->$tag(''";
                 };
             };
@@ -372,15 +373,15 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag eq 'filter') {
             my $key = $attr{'name'} || 'id';
 
-            if ($context[$#context] eq 'order') {
+            if ($context[-1] eq 'order') {
                 return "\n\$_xsp_handel_order_load_filter{'$key'} = ''";
-            } elsif ($context[$#context] eq 'orders') {
+            } elsif ($context[-1] eq 'orders') {
                 return "\n\$_xsp_handel_orders_load_filter{'$key'} = ''";
-            } elsif ($context[$#context] eq 'item') {
+            } elsif ($context[-1] eq 'item') {
                 return "\n\$_xsp_handel_order_item_filter{'$key'} = ''";
-            } elsif ($context[$#context] eq 'items') {
+            } elsif ($context[-1] eq 'items') {
                 return "\n\$_xsp_handel_order_items_filter{'$key'} = ''";
-            } elsif ($context[$#context] eq 'cart') {
+            } elsif ($context[-1] eq 'cart') {
                 return "\n\$_xsp_handel_order_new_cart_filter{'$key'} = ''";
             };
 
@@ -389,11 +390,11 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag =~ /^result(s?)$/) {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] !~ /^(new|add|order(s?)|item(s?))$/);
+            ) if ($context[-1] !~ /^(new|add|order(s?)|item(s?))$/);
 
             push @context, $tag;
 
-            if ($context[$#context-1] eq 'new') {
+            if ($context[-2] eq 'new') {
                 return '
                     if (!$_xsp_handel_order_called_new && scalar keys %_xsp_handel_order_new_filter) {
                         $_xsp_handel_order_order = Handel::Order->create(\%_xsp_handel_order_new_filter, $_xsp_handel_order_new_process);
@@ -402,7 +403,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                     if ($_xsp_handel_order_order) {
 
                 ';
-            } elsif ($context[$#context-1] eq 'order') {
+            } elsif ($context[-2] eq 'order') {
                 return '
                     if (!$_xsp_handel_order_called_load) {
                         $_xsp_handel_order_order = (scalar keys %_xsp_handel_order_load_filter) ?
@@ -413,7 +414,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                     if ($_xsp_handel_order_order) {
 
                 ';
-            } elsif ($context[$#context-1] eq 'orders') {
+            } elsif ($context[-2] eq 'orders') {
                 return '
                     if (!$_xsp_handel_orders_called_load) {
                         @_xsp_handel_order_orders = (scalar keys %_xsp_handel_orders_load_filter) ?
@@ -424,7 +425,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                     foreach my $_xsp_handel_order_order (@_xsp_handel_order_orders) {
 
                 ';
-            } elsif ($context[$#context-1] eq 'item') {
+            } elsif ($context[-2] eq 'item') {
                 return '
                     if (!$_xsp_handel_order_called_item) {
                         $_xsp_handel_order_item = (scalar keys %_xsp_handel_order_item_filter) ?
@@ -435,7 +436,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                     if ($_xsp_handel_order_item) {
 
                 ';
-            } elsif ($context[$#context-1] eq 'items') {
+            } elsif ($context[-2] eq 'items') {
                 return '
                     if (!$_xsp_handel_order_called_items) {
                         @_xsp_handel_order_items = (scalar keys %_xsp_handel_order_items_filter) ?
@@ -446,7 +447,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                     foreach my $_xsp_handel_order_item (@_xsp_handel_order_items) {
 
                 ';
-            } elsif ($context[$#context-1] eq 'add') {
+            } elsif ($context[-2] eq 'add') {
                 return '
                     if (!$_xsp_handel_order_called_add && scalar keys %_xsp_handel_order_add_filter) {
                         $_xsp_handel_order_item = $_xsp_handel_order_order->add(\%_xsp_handel_order_add_filter);
@@ -462,11 +463,11 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         } elsif ($tag =~ /^no-result(s?)$/) {
             throw Handel::Exception::Taglib(
                 -text => translate("Tag '[_1]' not valid here", $tag)
-            ) if ($context[$#context] !~ /^(new|add|order(s?)|item(s?))$/);
+            ) if ($context[-1] !~ /^(new|add|order(s?)|item(s?))$/);
 
             push @context, $tag;
 
-            if ($context[$#context-1] eq 'new') {
+            if ($context[-2] eq 'new') {
                 return '
                     if (!$_xsp_handel_order_called_new && scalar keys %_xsp_handel_order_new_filter) {
                         $_xsp_handel_order_order = Handel::Order->create(\%_xsp_handel_order_new_filter, $_xsp_handel_order_new_process);
@@ -474,7 +475,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                     };
                     if (!$_xsp_handel_order_order) {
                 ';
-            } elsif ($context[$#context-1] eq 'order') {
+            } elsif ($context[-2] eq 'order') {
                 return '
                     if (!$_xsp_handel_order_called_load) {
                         $_xsp_handel_order_order = (scalar keys %_xsp_handel_order_load_filter) ?
@@ -484,7 +485,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                     };
                     if (!$_xsp_handel_order_order) {
                 ';
-            } elsif ($context[$#context-1] eq 'orders') {
+            } elsif ($context[-2] eq 'orders') {
                 return '
                     if (!$_xsp_handel_orders_called_load) {
                         @_xsp_handel_order_orders = (scalar keys %_xsp_handel_orders_load_filter) ?
@@ -494,7 +495,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                     };
                     if (!scalar @_xsp_handel_order_orders) {
                 ';
-            } elsif ($context[$#context-1] eq 'item') {
+            } elsif ($context[-2] eq 'item') {
                 return '
                     if (!$_xsp_handel_order_called_item) {
                         $_xsp_handel_order_item = (scalar keys %_xsp_handel_order_item_filter) ?
@@ -504,7 +505,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                     };
                     if (!$_xsp_handel_order_item) {
                 ';
-            } elsif ($context[$#context-1] eq 'items') {
+            } elsif ($context[-2] eq 'items') {
                 return '
                     if (!$_xsp_handel_order_called_items) {
                         @_xsp_handel_order_items = (scalar keys %_xsp_handel_order_items_filter) ?
@@ -514,7 +515,7 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
                     };
                     if (!scalar @_xsp_handel_order_items) {
                 ';
-            } elsif ($context[$#context-1] eq 'add') {
+            } elsif ($context[-2] eq 'add') {
                 return '
                     if (!$_xsp_handel_order_called_add && scalar keys %_xsp_handel_order_add_filter) {
                         $_xsp_handel_order_item = $_xsp_handel_order_order->add(\%_xsp_handel_order_add_filter);
@@ -599,13 +600,13 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
 
         ## order:update
         } elsif ($tag eq 'update') {
-            if ($context[$#context-2] =~ /^(order(s?))$/) {
+            if ($context[-3] =~ /^(order(s?))$/) {
                 pop @context;
                 return '
                     $_xsp_handel_order_order->update;
                     $_xsp_handel_order_order->autoupdate(1);
                 ';
-            } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+            } elsif ($context[-3] =~ /^(item(s?))$/) {
                 pop @context;
                 return '
                     $_xsp_handel_order_item->update;
@@ -638,18 +639,18 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         shiptocity|shiptostate|shiptozip|shiptocountry|
         shiptodayphone|shiptonightphone|shiptofax|shiptoemail|
         tax|subtotal|updated)$/x) {
-            if ($context[$#context] eq 'new' && $tag !~ /^(count)$/) {
+            if ($context[-1] eq 'new' && $tag !~ /^(count)$/) {
                 return ";\n";
-            } elsif ($context[$#context] eq 'add' && $tag !~ /^(count|subtotal)$/) {
+            } elsif ($context[-1] eq 'add' && $tag !~ /^(count|subtotal)$/) {
                 return ";\n";
-            } elsif ($context[$#context] eq 'results') {
+            } elsif ($context[-1] eq 'results') {
                 $e->end_expr($tag);
-            } elsif ($context[$#context] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
+            } elsif ($context[-1] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
                 return ";\n";
-            } elsif ($context[$#context] eq 'update') {
-                if ($context[$#context-2] =~ /^(order(s?))$/) {
+            } elsif ($context[-1] eq 'update') {
+                if ($context[-3] =~ /^(order(s?))$/) {
                     return ");\n";
-                } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+                } elsif ($context[-3] =~ /^(item(s?))$/) {
                     return ");\n";
                 };
             };
@@ -658,28 +659,28 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
         ## order item property tags
         ## order:sku, price, quantity
         } elsif ($tag =~ /^(sku|price|quantity|total)$/) {
-            if ($context[$#context] eq 'add') {
+            if ($context[-1] eq 'add') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'new') {
+            } elsif ($context[-1] eq 'new') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'new') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'new') {
                 $e->end_expr($tag);
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'add') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'add') {
                 $e->end_expr($tag);
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'item') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'item') {
                 $e->end_expr($tag);
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'items') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'items') {
                 $e->end_expr($tag);
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'order') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'order') {
                 $e->end_expr($tag);
-            } elsif ($context[$#context] eq 'results' && $context[$#context-1] eq 'orders') {
+            } elsif ($context[-1] eq 'results' && $context[-2] eq 'orders') {
                 $e->end_expr($tag);
-            } elsif ($context[$#context] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
+            } elsif ($context[-1] eq 'delete' && $tag !~ /^(count|subtotal)$/) {
                 return ";\n";
-            } elsif ($context[$#context] eq 'update') {
-                if ($context[$#context-2] =~ /^(order(s?))$/) {
+            } elsif ($context[-1] eq 'update') {
+                if ($context[-3] =~ /^(order(s?))$/) {
                     return ");\n";
-                } elsif ($context[$#context-2] =~ /^(item(s?))$/) {
+                } elsif ($context[-3] =~ /^(item(s?))$/) {
                     return ");\n";
                 };
             };
@@ -687,44 +688,44 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
 
         ## order:filter
         } elsif ($tag eq 'filter') {
-            if ($context[$#context] eq 'order') {
+            if ($context[-1] eq 'order') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'orders') {
+            } elsif ($context[-1] eq 'orders') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'item') {
+            } elsif ($context[-1] eq 'item') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'items') {
+            } elsif ($context[-1] eq 'items') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'restore') {
+            } elsif ($context[-1] eq 'restore') {
                 return ";\n";
-            } elsif ($context[$#context] eq 'cart') {
+            } elsif ($context[-1] eq 'cart') {
                 return ";\n";
             };
 
 
         ## order:results
         } elsif ($tag =~ /^result(s?)$/) {
-            if ($context[$#context-1] eq 'new') {
+            if ($context[-2] eq 'new') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'order') {
+            } elsif ($context[-2] eq 'order') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'orders') {
+            } elsif ($context[-2] eq 'orders') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'item') {
+            } elsif ($context[-2] eq 'item') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'items') {
+            } elsif ($context[-2] eq 'items') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'add') {
+            } elsif ($context[-2] eq 'add') {
                 pop @context;
 
                 return "\n};\n";
@@ -734,27 +735,27 @@ $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Handel/Order';
 
         ## order:no-results
         } elsif ($tag =~ /^no-result(s?)$/) {
-            if ($context[$#context-1] eq 'new') {
+            if ($context[-2] eq 'new') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'order') {
+            } elsif ($context[-2] eq 'order') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'orders') {
+            } elsif ($context[-2] eq 'orders') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'item') {
+            } elsif ($context[-2] eq 'item') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'items') {
+            } elsif ($context[-2] eq 'items') {
                 pop @context;
 
                 return "\n};\n";
-            } elsif ($context[$#context-1] eq 'add') {
+            } elsif ($context[-2] eq 'add') {
                 pop @context;
 
                 return "\n};\n";
